lang.model.annex.spec-postgres.common


+pg-jsonb-shapes+clj

Explicit JSONB shapes accepted by deftype column metadata.

Explicit JSONB shapes accepted by deftype column metadata.
raw docstring

+pg-jsonb-types+clj

Types and aliases emitted as PostgreSQL jsonb.

Types and aliases emitted as PostgreSQL jsonb.
raw docstring

+pg-query-alias+clj


+pg-type-alias+clj


block-case-blockclj

(block-case-block value & args)

emits case block

emits case block
raw docstring

block-do-blockclj

(block-do-block form)

initates do block

initates do block
raw docstring

block-do-suppressclj

(block-do-suppress form)

initates suppress block

initates suppress block
raw docstring

block-loop-blockclj

(block-loop-block _ & forms)

emits loop block

emits loop block
raw docstring

block-while-blockclj

(block-while-block condition & forms)

emits while block

emits while block
raw docstring

pg-arrayclj

(pg-array [_ & arr] grammar mopts)

creates an array object

(common/pg-array '(array 1 2 3 4 5) g/+grammar+ {}) => "ARRAY[1,2,3,4,5]"

creates an array object

(common/pg-array '(array 1 2 3 4 5)
                 g/+grammar+
                 {})
=> "ARRAY[1,2,3,4,5]"
raw docstring

pg-base-tokenclj

(pg-base-token tok schtok)

creates a base token

creates a base token
raw docstring

pg-current-module-link?clj

(pg-current-module-link? current-module {:keys [module]})

checks whether a link points to the active module

checks whether a link points to the active module
raw docstring

pg-defblockclj

(pg-defblock [_ sym array])

creates generic defblock

creates generic defblock
raw docstring

pg-defenumclj

(pg-defenum [_ sym array])

defenum block

defenum block
raw docstring

pg-defindexclj

(pg-defindex [_ sym doc? attr? [table & cols] & body :as form])

defindex block

defindex block
raw docstring

pg-defpolicyclj

(pg-defpolicy [_ sym doc? attr? [table] body :as form])

defpolicy block

defpolicy block
raw docstring

pg-defpublicationclj

(pg-defpublication [_ sym doc? attr? args body :as form])

defpublication block

defpublication block
raw docstring

pg-defsubscriptionclj

(pg-defsubscription [_ sym doc? attr? [conn pub] body :as form])

defsubscription block

defsubscription block
raw docstring

pg-deftriggerclj

(pg-deftrigger [_ sym doc? attr? [table] body :as form])

TODO

TODO
raw docstring

pg-deftype-ref-nameclj

(pg-deftype-ref-name col {:keys [raw]})

gets the ref name

gets the ref name
raw docstring

pg-do-assertclj

(pg-do-assert [_ chk [tag data]] grammar mopts)

creates an assert form

creates an assert form
raw docstring

pg-entry-literalclj

(pg-entry-literal entry)

creates an entry literal

creates an entry literal
raw docstring

pg-entry-tokenclj

(pg-entry-token entry)

gets the entry token

gets the entry token
raw docstring

pg-formatclj

(pg-format [op sym & body])

formats a form, extracting static components

formats a form, extracting static components
raw docstring

pg-full-tokenclj

(pg-full-token tok schtok)

creates a full token (for types and enums)

creates a full token (for types and enums)
raw docstring

pg-hydrateclj

(pg-hydrate [op sym & body] grammar mopts)

hydrate function for top level entries

hydrate function for top level entries
raw docstring

pg-hydrate-module-staticclj

(pg-hydrate-module-static module)

gets the static module

gets the static module
raw docstring

pg-invoke-typecastclj

(pg-invoke-typecast form grammar mopts)

emits a typecast call

emits a typecast call
raw docstring

pg-jsonb-type?clj

(pg-jsonb-type? type)

Returns true when a deftype column type emits PostgreSQL jsonb.

Returns true when a deftype column type emits PostgreSQL jsonb.
raw docstring

(pg-link-symbol {:keys [module id]})

creates a fully qualified symbol for a link

creates a fully qualified symbol for a link
raw docstring

pg-linkedclj

(pg-linked sym grammar opts)

emits the linked symbol

emits the linked symbol
raw docstring

pg-linked-tokenclj

(pg-linked-token sym mopts)

gets the linked token given symbol

gets the linked token given symbol
raw docstring

pg-mapclj

(pg-map m grammar mopts)

creates a postgres json object

creates a postgres json object
raw docstring

pg-policy-formatclj

(pg-policy-format form)

TODO

TODO
raw docstring

pg-publication-formatclj

(pg-publication-format form)

formats publication

formats publication
raw docstring

pg-resolve-entryclj

(pg-resolve-entry link {:keys [book snapshot module lang] :as _mopts})

resolves a postgres link against the live module first, then the snapshot book, then vars

resolves a postgres link against the live module first, then the snapshot book, then vars
raw docstring

pg-setclj

(pg-set e grammar mopts)

makes a set object

makes a set object
raw docstring

pg-stringclj

(pg-string s)

constructs a pg string

constructs a pg string
raw docstring

pg-subscription-formatclj

(pg-subscription-format form)

formats subscription

formats subscription
raw docstring

pg-sym-metaclj

(pg-sym-meta sym)

returns the sym meta

returns the sym meta
raw docstring

pg-type-aliasclj

(pg-type-alias type)

gets the type alias

gets the type alias
raw docstring

pg-typecastclj

(pg-typecast [_ sym & args] grammar mopts)

creates a typecast

creates a typecast
raw docstring

pg-uuidclj

(pg-uuid u)

constructs a pg uuid

constructs a pg uuid
raw docstring

validate-pg-jsonb-metadataclj

(validate-pg-jsonb-metadata {:keys [type shape] :as attrs})

Validates JSONB shape metadata without changing the emitted SQL type.

:map and :array remain aliases for PostgreSQL jsonb. The metadata is only consumed by typed parsers and downstream schema conversion.

Validates JSONB shape metadata without changing the emitted SQL type.

:map and :array remain aliases for PostgreSQL jsonb. The metadata is only
consumed by typed parsers and downstream schema conversion.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries