lang.model.annex.spec-postgres.form-deftype-hydrate


pg-deftype-hydrateclj

(pg-deftype-hydrate [op sym spec params]
                    grammar
                    {:keys [module book snapshot] :as mopts})

hydrates the form with linked ref information

hydrates the form with linked ref information
raw docstring

pg-deftype-hydrate-attrclj

(pg-deftype-hydrate-attr k
                         {:keys [type primary ref sql scope foreign] :as attrs}
                         {:keys [resolve-link-fn snapshot module capture]
                          :as mopts})

hydrates a single attribute

hydrates a single attribute
raw docstring

(pg-deftype-hydrate-check-link snapshot module link type)

checks a link making sure it exists and is correct type

checks a link making sure it exists and is correct type
raw docstring

pg-deftype-hydrate-hookclj

(pg-deftype-hydrate-hook entry)

updates the application schema

updates the application schema
raw docstring

(pg-deftype-hydrate-link sym module {:keys [ns] :as ref})

resolves the link for hydration

resolves the link for hydration
raw docstring

pg-deftype-hydrate-process-enumclj

(pg-deftype-hydrate-process-enum k attrs resolve-link-fn snapshot module)

processes the enum type

processes the enum type
raw docstring

pg-deftype-hydrate-process-foreignclj

(pg-deftype-hydrate-process-foreign foreign resolve-link-fn snapshot module)

processes the foreign attribute

processes the foreign attribute
raw docstring

pg-deftype-hydrate-process-refclj

(pg-deftype-hydrate-process-ref k
                                {:keys [ref] :as attrs}
                                resolve-link-fn
                                snapshot
                                module)

processes the ref type

processes the ref type
raw docstring

pg-deftype-hydrate-process-sqlclj

(pg-deftype-hydrate-process-sql sql k attrs module)

processes the sql attribute

processes the sql attribute
raw docstring

pg-deftype-hydrate-specclj

(pg-deftype-hydrate-spec spec mopts)

hydrates the spec

hydrates the spec
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries