Explicit JSONB shapes accepted by deftype column metadata.
Explicit JSONB shapes accepted by deftype column metadata.
Types and aliases emitted as PostgreSQL jsonb.
Types and aliases emitted as PostgreSQL jsonb.
(block-do-suppress form)initates suppress block
initates suppress block
(block-while-block condition & forms)emits while block
emits while block
(pg-array [_ & arr] grammar mopts)creates an array object
(common/pg-array '(array 1 2 3 4 5) g/+grammar+ {}) => "ARRAY[1,2,3,4,5]"
creates an array object
(common/pg-array '(array 1 2 3 4 5)
g/+grammar+
{})
=> "ARRAY[1,2,3,4,5]"(pg-current-module-link? current-module {:keys [module]})checks whether a link points to the active module
checks whether a link points to the active module
(pg-defblock [_ sym array])creates generic defblock
creates generic defblock
(pg-defindex [_ sym doc? attr? [table & cols] & body :as form])defindex block
defindex block
(pg-defpolicy [_ sym doc? attr? [table] body :as form])defpolicy block
defpolicy block
(pg-defpublication [_ sym doc? attr? args body :as form])defpublication block
defpublication block
(pg-defsubscription [_ sym doc? attr? [conn pub] body :as form])defsubscription block
defsubscription block
(pg-deftype-ref-name col {:keys [raw]})gets the ref name
gets the ref name
(pg-do-assert [_ chk [tag data]] grammar mopts)creates an assert form
creates an assert form
(pg-entry-literal entry)creates an entry literal
creates an entry literal
(pg-format [op sym & body])formats a form, extracting static components
formats a form, extracting static components
(pg-full-token tok schtok)creates a full token (for types and enums)
creates a full token (for types and enums)
(pg-hydrate [op sym & body] grammar mopts)hydrate function for top level entries
hydrate function for top level entries
(pg-hydrate-module-static module)gets the static module
gets the static module
(pg-invoke-typecast form grammar mopts)emits a typecast call
emits a typecast call
(pg-jsonb-type? type)Returns true when a deftype column type emits PostgreSQL jsonb.
Returns true when a deftype column type emits PostgreSQL jsonb.
(pg-link-symbol {:keys [module id]})creates a fully qualified symbol for a link
creates a fully qualified symbol for a link
(pg-linked sym grammar opts)emits the linked symbol
emits the linked symbol
(pg-linked-token sym mopts)gets the linked token given symbol
gets the linked token given symbol
(pg-map m grammar mopts)creates a postgres json object
creates a postgres json object
(pg-publication-format form)formats publication
formats publication
(pg-resolve-entry link {:keys [book snapshot module lang] :as _mopts})resolves a postgres link against the live module first, then the snapshot book, then vars
resolves a postgres link against the live module first, then the snapshot book, then vars
(pg-subscription-format form)formats subscription
formats subscription
(pg-typecast [_ sym & args] grammar mopts)creates a typecast
creates a typecast
(validate-pg-jsonb-metadata {:keys [type shape] :as attrs})Validates JSONB shape metadata without changing the emitted SQL type.
:map and :array remain aliases for PostgreSQL jsonb. The metadata is only consumed by typed parsers and downstream schema conversion.
Validates JSONB shape metadata without changing the emitted SQL type. :map and :array remain aliases for PostgreSQL jsonb. The metadata is only consumed by typed parsers and downstream schema conversion.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |