postgres.core.addon


ARRAYclj

(ARRAY & args)

creates an array

creates an array
raw docstring

assertclj

(assert chk [tag data])

asserts given a block

asserts given a block
raw docstring

b:deleteclj

(b:delete & args)

delete macro

delete macro
raw docstring

b:insertclj

(b:insert & args)

insert macro

insert macro
raw docstring

b:selectclj

(b:select & args)

basic select macro

basic select macro
raw docstring

b:updateclj

(b:update & args)

update macro

update macro
raw docstring

caseclj

(case & args)

builds a case form

builds a case form
raw docstring

client-listclj

(client-list)

gets the client list for pg

gets the client list for pg
raw docstring

coordclj

(coord table row-id)

gets the coordinate of a row

gets the coordinate of a row
raw docstring

do:plpgsqlclj

(do:plpgsql & forms)

creates a do block

creates a do block
raw docstring

do:reduceclj

(do:reduce out f type arr)

basic reduce macro

basic reduce macro
raw docstring

errorclj

(error {:as m})

raises a json error with value

raises a json error with value
raw docstring

execclj

(exec args)

executes an sql statement

executes an sql statement
raw docstring

field-idclj

(field-id m field)

shorthand for getting the field-id for a linked map

shorthand for getting the field-id for a linked map
raw docstring

fullclj

(full table)

gets the full jsonb for table or function

gets the full jsonb for table or function
raw docstring

full-strclj

(full-str table)

gets the full json str form table or function

gets the full json str form table or function
raw docstring

get-stack-diagnosticsclj

(get-stack-diagnostics)

gets the stack diagnostics

gets the stack diagnostics
raw docstring

idclj

(id sym & [type])

gets the id of an object

gets the id of an object
raw docstring

map:jsclj

(map:js f arr & args)

basic map across json

basic map across json
raw docstring

map:js-textclj

(map:js-text f arr & args)

maps across json

maps across json
raw docstring

map:relclj

(map:rel f rel & args)

basic map across relation

basic map across relation
raw docstring

nameclj

(name table)

gets the name of a table

gets the name of a table
raw docstring

performclj

(perform & args)

perform macro

perform macro
raw docstring

rand-hexclj

(rand-hex n)

generates random hex

generates random hex
raw docstring

random-enumclj

(random-enum enum)

gets random enum

gets random enum
raw docstring

retclj

(ret & args)

returns a value alias for select

returns a value alias for select
raw docstring

sha1clj

(sha1 text)

calculates the sha1

calculates the sha1
raw docstring

throwclj

(throw {:as m})

raises a json exception

raises a json exception
raw docstring

time-msclj

(time-ms)

returns the time in ms

returns the time in ms
raw docstring

time-usclj

(time-us)

returns the time in us

returns the time in us
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries