(defret-fn args query)the defref generator function
the defref generator function
(defret.pg sym args query)creates a returns function
creates a returns function
(defsel-fn query)the defsel generator function
the defsel generator function
(defsel.pg sym & [query])creates a select function
creates a select function
(primary-key table-sym)gets the type of the first primary key column of a schema
gets the type of the first primary key column of a schema
(view-fn qret qsel qopts)constructs a view function
constructs a view function
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |