postgres.core.supabase


alter-role-bypassrlsclj

(alter-role-bypassrls role)

alters role to bypass rls

alters role to bypass rls
raw docstring

auth-emailclj

(auth-email)

calls auth.email()

calls auth.email()
raw docstring

auth-jwtclj

(auth-jwt)

calls auth.jwt()

calls auth.jwt()
raw docstring

auth-roleclj

(auth-role)

calls auth.role()

calls auth.role()
raw docstring

auth-uidclj

(auth-uid)

calls auth.uid()

calls auth.uid()
raw docstring

create-roleclj

(create-role role)

creates a role

creates a role
raw docstring

get-form-typeclj

(get-form-type form)

gets the form type

gets the form type
raw docstring

grant-allclj

(grant-all schemas & [roles access])

grants privileges on a schema

grants privileges on a schema
raw docstring

grant-privilegesclj

(grant-privileges schema & [roles])

grants privileges on a schema

grants privileges on a schema
raw docstring

grant-publicclj

(grant-public schema)

grants public access to schema

grants public access to schema
raw docstring

grant-tablesclj

(grant-tables schema & [roles])

grants table access on a schema

grants table access on a schema
raw docstring

grant-usageclj

(grant-usage schema & [roles])

grants usage on a schema

grants usage on a schema
raw docstring

is-supabaseclj

(is-supabase)

checks that supabase is installed

checks that supabase is installed
raw docstring

normalize-realtime-payloadclj

(normalize-realtime-payload payload)

Normalizes literal map payloads into postgres jsonb forms.

Normalizes literal map payloads into postgres jsonb forms.
raw docstring

process-returnclj

(process-return ret)

processes the return value

processes the return value
raw docstring

raiseclj

(raise message detail &)

raises an error

raises an error
raw docstring

realtime-sendclj

(realtime-send topic event payload)
(realtime-send topic event payload private?)

calls Supabase realtime.send with payload, event, topic, and privacy flag

calls Supabase realtime.send with payload, event, topic, and privacy flag
raw docstring

realtime-send-requestclj

(realtime-send-request topic request)
(realtime-send-request topic request private?)

broadcasts a native xt.db request through Supabase realtime.send

broadcasts a native xt.db request through Supabase realtime.send
raw docstring

realtime-topicclj

(realtime-topic)

returns the topic being authorized by a realtime.messages RLS policy

returns the topic being authorized by a realtime.messages RLS policy
raw docstring

request-eventclj

(request-event request)

Returns the canonical xt.db event name for an xt.db request.

Returns the canonical xt.db event name for an xt.db request.
raw docstring

resolve-literalclj

(resolve-literal form)

Resolves literal data carried directly or via a bound var.

Resolves literal data carried directly or via a bound var.
raw docstring

revoke-execute-privileges-from-publicclj

(revoke-execute-privileges-from-public schema)

revotes execute privileges

revotes execute privileges
raw docstring

show-rolesclj

(show-roles)

show supabase role information

show supabase role information
raw docstring

transform-entryclj

(transform-entry body {:keys [grammar entry mopts] :as env})

transforms a book entry

transforms a book entry
raw docstring

transform-entry-defnclj

(transform-entry-defn body {:keys [grammar entry mopts] :as env})

transforms a defn entry

transforms a defn entry
raw docstring

transform-entry-deftypeclj

(transform-entry-deftype body {:keys [grammar entry mopts] :as env})

transforms a deftype

transforms a deftype
raw docstring

with-authcljmacro

(with-auth [user-id type] & forms)

executes a statement with auth

executes a statement with auth
raw docstring

with-auth-singlecljmacro

(with-auth-single [user-id type] form)

executes a statement with auth (single)

executes a statement with auth (single)
raw docstring

with-rolecljmacro

(with-role [role type] & forms)

executes a statement with role

executes a statement with role
raw docstring

with-role-singlecljmacro

(with-role-single [role type] form)

executes a statement with role (single)

executes a statement with role (single)
raw docstring

with-supercljmacro

(with-super [user-id type] & forms)

executes a statement with super

executes a statement with super
raw docstring

with-super-singlecljmacro

(with-super-single [user-id type] form)

executes a statement with super (single)

executes a statement with super (single)
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries