postgres.typed.export.json-openapi


arg->openapiclj

(arg->openapi arg fn-def)

Converts a function argument to OpenAPI parameter schema. For :jsonb types that map to table inputs, uses the table's shape.

Converts a function argument to OpenAPI parameter schema.
For :jsonb types that map to table inputs, uses the table's shape.
raw docstring

field->openapiclj

(field->openapi field-info)

Converts a field descriptor to OpenAPI schema.

Converts a field descriptor to OpenAPI schema.
raw docstring

fn->openapiclj

(fn->openapi fn-def)

Converts a FnDef to OpenAPI operation.

Converts a FnDef to OpenAPI operation.
raw docstring

generate-openapiclj

(generate-openapi root-ns fn-filter)
(generate-openapi root-ns
                  fn-filter
                  {:keys [function-order schema-order registration-order]})

Generates complete OpenAPI 3.0 spec.

Generates complete OpenAPI 3.0 spec.
raw docstring

shape->openapiclj

(shape->openapi shape)

Converts a JsonbShape to OpenAPI schema object.

Converts a JsonbShape to OpenAPI schema object.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries