Clojure only.

postgres.typed.export.json-view

Compiles bound postgres view descriptors into the published JSON view registry.

Compiles bound postgres view descriptors into the published JSON view registry.
raw docstring

generate-viewsclj

(generate-views entries)

Builds the versioned JSON publication for typed postgres views.

Entries are the [symbol descriptor] values returned by postgres.typed.typed-view/view-entries.

Builds the versioned JSON publication for typed postgres views.

Entries are the `[symbol descriptor]` values returned by
`postgres.typed.typed-view/view-entries`.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries