postgres.typed.export.portable-edn


export-ednclj

(export-edn ctx)

Returns a versioned, plain EDN data structure for a postgres typed context.

Pretty print the result with clojure.pprint/pprint or serialize it with pr-str. Read serialized text with clojure.edn/read-string before passing it to import-edn. Function filters are runtime values and therefore must be supplied again to APIs such as export-openapi after importing.

Returns a versioned, plain EDN data structure for a postgres typed context.

Pretty print the result with `clojure.pprint/pprint` or serialize it with
`pr-str`. Read serialized text with `clojure.edn/read-string` before passing
it to `import-edn`.
Function filters are runtime values and therefore must be supplied again to
APIs such as `export-openapi` after importing.
raw docstring

import-ednclj

(import-edn snapshot)

Returns a postgres typed context from a snapshot data structure.

Returns a postgres typed context from a snapshot data structure.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries