postgres.typed.export.server-db


+targets+clj


collect-pg-opsclj

(collect-pg-ops form)

db-sync-mergeclj

(db-sync-merge output table-names)

Default sync helper used by generated DB-server wrappers.

Default sync helper used by generated DB-server wrappers.
raw docstring

emit-targetclj

(emit-target fn-def target)

Emits generated source for a single DB-server target.

Emits generated source for a single DB-server target.
raw docstring

emit-targetsclj

(emit-targets fn-def & [targets])

Emits generated source for multiple DB-server targets.

Emits generated source for multiple DB-server targets.
raw docstring

infer-sync-specclj

(infer-sync-spec fn-def)

Infers a minimal sync generation spec for a FnDef.

Infers a minimal sync generation spec for a FnDef.
raw docstring

list-targetsclj

(list-targets)

Lists supported DB-server generation targets.

Lists supported DB-server generation targets.
raw docstring

supabase-db-inputclj

(supabase-db-input {:keys [wrapper-sym fn-def sync-spec]})

Template input for the :supabase-db target.

Template input for the `:supabase-db` target.
raw docstring

target-entryclj

(target-entry fn-def target)

Creates a target emission entry for a DB-server target.

Creates a target emission entry for a DB-server target.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries