postgres.typed.typed-infer


find-table-op-in-bodyclj

(find-table-op-in-body body arg-name)

Searches body for pg/t:insert or pg/g:insert calls with arg-name. Also traces through derived let bindings and function calls. Returns the table symbol if found, nil otherwise.

Searches body for pg/t:insert or pg/g:insert calls with arg-name.
Also traces through derived let bindings and function calls.
Returns the table symbol if found, nil otherwise.
raw docstring

find-table-track-spec-in-bodyclj

(find-table-track-spec-in-body body arg-name)

Searches body for pg/t:update or pg/t:insert forms that consume arg-name via :track. Returns a map with table and track form when found.

Searches body for pg/t:update or pg/t:insert forms that consume arg-name
via :track. Returns a map with table and track form when found.
raw docstring

find-table-update-spec-in-bodyclj

(find-table-update-spec-in-body body arg-name)

Searches body for pg/t:update or pg/g:update forms that consume arg-name in their :set payload. Returns a map with table and selected columns when found, nil otherwise.

Searches body for pg/t:update or pg/g:update forms that consume arg-name
in their :set payload. Returns a map with table and selected columns when
found, nil otherwise.
raw docstring

form-uses-track-param?clj

(form-uses-track-param? form tracked)

form-uses-tracked?clj

(form-uses-tracked? form tracked)

infer-jsonb-arg-access-shapeclj

(infer-jsonb-arg-access-shape arg-name fn-def)
(infer-jsonb-arg-access-shape arg-name fn-def seed-shape)
(infer-jsonb-arg-access-shape arg-name fn-def seed-shape role)

infer-jsonb-arg-shapeclj

(infer-jsonb-arg-shape arg-name fn-def & [role])

Infers a JsonbShape for a :jsonb argument when used with table operations.

Infers a JsonbShape for a :jsonb argument when used with table operations.
raw docstring

infer-jsonb-arg-shape*clj

(infer-jsonb-arg-shape* arg-name fn-def visited & [role])

infer-jsonb-arg-table-shape*clj

(infer-jsonb-arg-table-shape* arg-name fn-def visited)

resolve-table-defclj

(resolve-table-def table-sym)

Resolves a table symbol from the type registry.

Resolves a table symbol from the type registry.
raw docstring

select-shape-columnsclj

(select-shape-columns base-shape cols)

Restricts a JsonbShape to the selected columns, preserving shape metadata.

Restricts a JsonbShape to the selected columns, preserving shape metadata.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries