(pg-deftype-hydrate [op sym spec params]
grammar
{:keys [module book snapshot] :as mopts})hydrates the form with linked ref information
hydrates the form with linked ref information
(pg-deftype-hydrate-attr k
{:keys [type primary ref sql scope foreign] :as attrs}
{:keys [resolve-link-fn snapshot module capture]
:as mopts})hydrates a single attribute
hydrates a single attribute
(pg-deftype-hydrate-check-link snapshot module link type)checks a link making sure it exists and is correct type
checks a link making sure it exists and is correct type
(pg-deftype-hydrate-hook entry)updates the application schema
updates the application schema
(pg-deftype-hydrate-link sym module {:keys [ns] :as ref})resolves the link for hydration
resolves the link for hydration
(pg-deftype-hydrate-process-enum k attrs resolve-link-fn snapshot module)processes the enum type
processes the enum type
(pg-deftype-hydrate-process-foreign foreign resolve-link-fn snapshot module)processes the foreign attribute
processes the foreign attribute
(pg-deftype-hydrate-process-ref k
{:keys [ref] :as attrs}
resolve-link-fn
snapshot
module)processes the ref type
processes the ref type
(pg-deftype-hydrate-process-sql sql k attrs module)processes the sql attribute
processes the sql attribute
(pg-deftype-hydrate-spec spec mopts)hydrates the spec
hydrates the spec
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |