(alter-role-bypassrls role)alters role to bypass rls
alters role to bypass rls
(grant-all schemas & [roles access])grants privileges on a schema
grants privileges on a schema
(grant-privileges schema & [roles])grants privileges on a schema
grants privileges on a schema
(grant-public schema)grants public access to schema
grants public access to schema
(grant-tables schema & [roles])grants table access on a schema
grants table access on a schema
(grant-usage schema & [roles])grants usage on a schema
grants usage on a schema
(is-supabase)checks that supabase is installed
checks that supabase is installed
(normalize-realtime-payload payload)Normalizes literal map payloads into postgres jsonb forms.
Normalizes literal map payloads into postgres jsonb forms.
(process-return ret)processes the return value
processes the return value
(realtime-send topic event payload)(realtime-send topic event payload private?)calls Supabase realtime.send with payload, event, topic, and privacy flag
calls Supabase realtime.send with payload, event, topic, and privacy flag
(realtime-send-request topic request)(realtime-send-request topic request private?)broadcasts a native xt.db request through Supabase realtime.send
broadcasts a native xt.db request through Supabase realtime.send
(realtime-topic)returns the topic being authorized by a realtime.messages RLS policy
returns the topic being authorized by a realtime.messages RLS policy
(request-event request)Returns the canonical xt.db event name for an xt.db request.
Returns the canonical xt.db event name for an xt.db request.
(resolve-literal form)Resolves literal data carried directly or via a bound var.
Resolves literal data carried directly or via a bound var.
(revoke-execute-privileges-from-public schema)revotes execute privileges
revotes execute privileges
(show-roles)show supabase role information
show supabase role information
(transform-entry body {:keys [grammar entry mopts] :as env})transforms a book entry
transforms a book entry
(transform-entry-defn body {:keys [grammar entry mopts] :as env})transforms a defn entry
transforms a defn entry
(transform-entry-deftype body {:keys [grammar entry mopts] :as env})transforms a deftype
transforms a deftype
(with-auth [user-id type] & forms)executes a statement with auth
executes a statement with auth
(with-auth-single [user-id type] form)executes a statement with auth (single)
executes a statement with auth (single)
(with-role [role type] & forms)executes a statement with role
executes a statement with role
(with-role-single [role type] form)executes a statement with role (single)
executes a statement with role (single)
(with-super [user-id type] & forms)executes a statement with super
executes a statement with super
(with-super-single [user-id type] form)executes a statement with super (single)
executes a statement with super (single)
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |