(emit-module-entry api-type [sym descriptor])Emits one templated def.xt entry from a descriptor map.
Emits one templated def.xt entry from a descriptor map.
(emit-route-entries ns)(emit-route-entries ns root)Emits all def.xt route entries for a postgres module namespace.
Emits all `def.xt` route entries for a postgres module namespace.
(emit-route-entry src)(emit-route-entry src root)Emits a single def.xt route entry for a postgres function symbol.
Emits a single `def.xt` route entry for a postgres function symbol.
(generate-ns target-ns src-ns)Generates a route namespace file from a postgres module namespace.
Generates a route namespace file from a postgres module namespace.
(namespace-body target-ns src-ns)Creates the source body for a generated route namespace.
Creates the source body for a generated route namespace.
(namespace-url-root ns)Creates a default API root from a postgres module namespace.
Creates a default API root from a postgres module namespace.
(render-module target-ns api-type entries & [{:keys [header]}])Renders a monolithic XTalk module from descriptor entries.
Renders a monolithic XTalk module from descriptor entries.
(route-entries source-namespaces)(route-entries source-namespaces pred)(route-entries source-namespaces pred opts)Binds functions from one or more generated RPC namespaces. The predicate
receives a std.lang entry and defaults to all functions. Results are
deterministic and duplicate route ids fail generation. Source order can be
retained with :preserve-source-order?; the default remains sorted for
compatibility.
Binds functions from one or more generated RPC namespaces. The predicate receives a std.lang entry and defaults to all functions. Results are deterministic and duplicate route ids fail generation. Source order can be retained with `:preserve-source-order?`; the default remains sorted for compatibility.
(route-entry-input {:keys [src route-sym root]})Creates template input for a generated def.xt route entry.
Creates template input for a generated `def.xt` route entry.
(target-path target-ns src-ns)Resolves the output path for a generated namespace using the source namespace root.
Resolves the output path for a generated namespace using the source namespace root.
(view-entries source-namespaces)(view-entries source-namespaces opts)Binds defsel.pg/defret.pg entries from one or more namespaces into the
standard xt.db.node dataview descriptors. Results are deterministic and
duplicate view ids fail generation. Source order can be retained with
:preserve-source-order?; the default remains sorted for compatibility.
Binds defsel.pg/defret.pg entries from one or more namespaces into the standard xt.db.node dataview descriptors. Results are deterministic and duplicate view ids fail generation. Source order can be retained with `:preserve-source-order?`; the default remains sorted for compatibility.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |