(arg->openapi arg fn-def)Converts a function argument to OpenAPI parameter schema. For :jsonb types that map to table inputs, uses the table's shape.
Converts a function argument to OpenAPI parameter schema. For :jsonb types that map to table inputs, uses the table's shape.
(field->openapi field-info)Converts a field descriptor to OpenAPI schema.
Converts a field descriptor to OpenAPI schema.
(fn->openapi fn-def)Converts a FnDef to OpenAPI operation.
Converts a FnDef to OpenAPI operation.
(generate-openapi root-ns fn-filter)(generate-openapi root-ns
fn-filter
{:keys [function-order schema-order registration-order]})Generates complete OpenAPI 3.0 spec.
Generates complete OpenAPI 3.0 spec.
(shape->openapi shape)Converts a JsonbShape to OpenAPI schema object.
Converts a JsonbShape to OpenAPI schema object.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |