Compiles bound postgres view descriptors into the published JSON view registry.
Compiles bound postgres view descriptors into the published JSON view registry.
(generate-views entries)Builds the versioned JSON publication for typed postgres views.
Entries are the [symbol descriptor] values returned by
postgres.typed.typed-view/view-entries.
Builds the versioned JSON publication for typed postgres views. Entries are the `[symbol descriptor]` values returned by `postgres.typed.typed-view/view-entries`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |