(collect-pg-ops form)(db-sync-merge output table-names)Default sync helper used by generated DB-server wrappers.
Default sync helper used by generated DB-server wrappers.
(emit-target fn-def target)Emits generated source for a single DB-server target.
Emits generated source for a single DB-server target.
(emit-targets fn-def & [targets])Emits generated source for multiple DB-server targets.
Emits generated source for multiple DB-server targets.
(infer-sync-spec fn-def)Infers a minimal sync generation spec for a FnDef.
Infers a minimal sync generation spec for a FnDef.
(list-targets)Lists supported DB-server generation targets.
Lists supported DB-server generation targets.
(supabase-db-input {:keys [wrapper-sym fn-def sync-spec]})Template input for the :supabase-db target.
Template input for the `:supabase-db` target.
(target-entry fn-def target)Creates a target emission entry for a DB-server target.
Creates a target emission entry for a DB-server target.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |