(find-table-op-in-body body arg-name)Searches body for pg/t:insert or pg/g:insert calls with arg-name. Also traces through derived let bindings and function calls. Returns the table symbol if found, nil otherwise.
Searches body for pg/t:insert or pg/g:insert calls with arg-name. Also traces through derived let bindings and function calls. Returns the table symbol if found, nil otherwise.
(find-table-track-spec-in-body body arg-name)Searches body for pg/t:update or pg/t:insert forms that consume arg-name via :track. Returns a map with table and track form when found.
Searches body for pg/t:update or pg/t:insert forms that consume arg-name via :track. Returns a map with table and track form when found.
(find-table-update-spec-in-body body arg-name)Searches body for pg/t:update or pg/g:update forms that consume arg-name in their :set payload. Returns a map with table and selected columns when found, nil otherwise.
Searches body for pg/t:update or pg/g:update forms that consume arg-name in their :set payload. Returns a map with table and selected columns when found, nil otherwise.
(form-uses-track-param? form tracked)(form-uses-tracked? form tracked)(infer-jsonb-arg-access-shape arg-name fn-def)(infer-jsonb-arg-access-shape arg-name fn-def seed-shape)(infer-jsonb-arg-access-shape arg-name fn-def seed-shape role)(infer-jsonb-arg-shape arg-name fn-def & [role])Infers a JsonbShape for a :jsonb argument when used with table operations.
Infers a JsonbShape for a :jsonb argument when used with table operations.
(infer-jsonb-arg-shape* arg-name fn-def visited & [role])(infer-jsonb-arg-table-shape* arg-name fn-def visited)(resolve-table-def table-sym)Resolves a table symbol from the type registry.
Resolves a table symbol from the type registry.
(select-shape-columns base-shape cols)Restricts a JsonbShape to the selected columns, preserving shape metadata.
Restricts a JsonbShape to the selected columns, preserving shape metadata.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |