(access-field shape field-name accessor-type)Extracts a field type from a shape. Used by analyzer for :-> and :->> ops.
Extracts a field type from a shape. Used by analyzer for :-> and :->> ops.
(map-schema->shape map-schema)Converts a map schema definition to a JsonbShape.
Converts a map schema definition to a JsonbShape.
(map-schema-entry->field-type entry-key entry-val)Converts a single map schema entry to a field descriptor. Handles nested map schemas recursively.
Converts a single map schema entry to a field descriptor. Handles nested map schemas recursively.
(resolve-column-type col)Resolves a ColumnDef's type to a field descriptor. Handles explicit JSONB shapes and nested map schemas for JSONB columns.
Resolves a ColumnDef's type to a field descriptor. Handles explicit JSONB shapes and nested map schemas for JSONB columns.
(shape->map shape)Converts a shape to a plain map (for debugging/API).
Converts a shape to a plain map (for debugging/API).
(shape-for-table-op op table-def opts)Returns the appropriate type/shape for a table operation.
Returns the appropriate type/shape for a table operation.
(table->shape table-def)(table->shape table-def class-table)Converts a TableDef to a JsonbShape. SINGLE SOURCE OF TRUTH. Guarantees:
Converts a TableDef to a JsonbShape. SINGLE SOURCE OF TRUTH. Guarantees: - Ref fields get -id suffix (e.g., :org -> :org-id) - Primary keys are always non-nullable.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |